;=======================
;
; Dodger v2.0
;  by Cullen Sauls
;
; Title Screen Effect: Aaron Curtis
;
; Contact:
;  webpage: http://cullen.macross2000.org
;  e-mail:  sauls@tamu.edu
;  ICQ:     11130342
;  AIM:     OrbitYFL
;
; Copyright  April 2003
;
; Source code looks best in Assembly Studio
;  Use Assembly Studio 8x project function for best results
;
;=======================

.plugin lite86

#include "ti86asm.inc"
#include "macros.h"

;TO DO
;
;[X] - Down-left bug
;[X] - Slow homing missile
;[X] - Control-swap graphic: invert
;[X] - Power-up on screen longer
;[X] - Stronger arrows
;[X] - Reduce speed of gravity wells / repellers ?
;[X] - Faster speed ?
;[X] - Clear highscore table with "clear"
;[X] - Turn off calc from Pause state
;---After beta is done---
;[X] - Change shell comment (take out "Beta")
;[X] - Reset high scores to zero
;[?] - Set power-up spawn rate to normal
;[X] - Pause (with contrast adjustment?)
;[?] - Title screen
;[-] - Easter eggs?

;#define DEBUG_FPS                           ;Will show the FPS if defined

VarStart            = _textShadow
RandSeedSave        = VarStart              ;[6]
NumObjects          = RandSeedSave+6        ;[1]
ManX                = NumObjects+1          ;[1]
ManY                = ManX+1                ;[1]
CurDelay            = ManY+1                ;[1]
StartDelay          = CurDelay+1            ;[1]
Level               = StartDelay+1          ;[1]
Score               = Level+1               ;[2]
Avoid               = Score+2               ;[1]
Life                = Avoid+1               ;[1]
ManSpeed            = Life+1                ;[1]
NumPU               = ManSpeed+1            ;[1]
PUCoolDown          = NumPU+1               ;[1]
NumPointStack       = PUCoolDown+1          ;[1]
DeathTimer          = NumPointStack+1       ;[1]
DeathFrame          = DeathTimer+1          ;[1]
MoveAnimFrame       = DeathFrame+1          ;[1]
MoveAnimTimer       = MoveAnimFrame+1       ;[1]
ManMove             = MoveAnimTimer+1       ;[1]
NoMoveTimer         = ManMove+1             ;[1]
NoMoveDelay         = NoMoveTimer+1         ;[1]
LevelSave           = NoMoveDelay+1         ;[1]
InterruptCounter    = LevelSave+1           ;[1] \
FPS                 = InterruptCounter+1    ;[1]  |For debugging purposes
DispFPS             = FPS+1                 ;[1] /

_user_int_ram       = $D2FD                 ;Area where interrupt handler goes

SCREENADDR          = $FC00
BUFFERADDR          = $CA00
STOREADDR           = $B000
OBJECTADDR          = $8200
;8 bytes per object: AIFunc (2),X (1),Y (1),Sprite (2),Spare (1),Spare (1)
;AI function is stored high-byte then low-byte, opposite of what is usually expected.
PUADDR              = $9000
;6 bytes per power-up: Exist (1), Active (1), X (1), Y(1), Type (1), Time (1)
POINTSTACK          = $9900
;holds numbers for amount of frames to elapse before points are given
OBJECTTABLE         = $9A00
RIGHTEDGE           = 104
UPBOUND             = 2
DOWNBOUND           = 55
LEFTBOUND           = 2
RIGHTBOUND          = 95

;#define BOUND_IS_ONE           ;uncomment if UPBOUND and LEFTBOUND are 1

NUMSETUPVARS        = 21

NUMOBJECTS          = 9
OBJECTAND           = 15
;1 3 7 15 31 63 127
NUMPOWERUP          = 15
POWERUPAND          = 15
;1 3 7 15 31 63 127
;(NUM - 1) <= AND

NUMNODAMAGEOBJECTS  = 0
;#define NODAMAGEOBJECTS        ;uncomment if NUMNODMGOBJECTS > 0

MOVEANIMTIME        = 3

NOMOVETIME          = 100       ;# of frames you can stand still before you start losing life.
NOMOVEDELAY         = 5         ;# of frames between life loss when standing still

LEVEL1DELAY         = 80
DELAYCHANGE         = 6
LEVELUPAVOID        = 15
MINDELAY            = 5

NUMDEATHFRAME       = 3
DEATHDELAY          = 30
;
;Object Constants
;
BOMBPOINTDELAY      = 85
BOMBDELAY           = 50
SHRAPNELTYPE2TIMER  = 6         ;needs be divisible by 3

SPARKPOINTDELAY     = 60
SPARKSPEED          = 2         ;# of pixels to move per frame

HMISSILEPOINTDELAY  = 60
HMISSILESPEED       = 2         ;# of pixels to move per frame

BLACKHOLEPOINTDELAY = 101
BLACKHOLEDELAY      = 100

REPELPOINTDELAY     = 101
REPELDELAY          = 100

BBALLPOINTDELAY     = 105
BBALLMODNUM         = 40        ;gravity control, high number makes it fall further

RICOCHETPOINTDELAY  = 205
RICOCHETTIME        = 200

DEATHORBPOINTDELAY  = 60
ORBOFDEATHDELAY     = 5         ;time in between ball throwings
ORBOFDEATHSPEED     = 1         ;# of pixels to move per frame

PACMANPOINTDELAY    = 60
PACMANANIMDELAY     = 5         ;# of frames in each animation state
PACMANSPEED         = 2
;
;Power-Up constants
;
PUDELAY             = 100       ;Time between possible power-up spawns
POWERUPTIME         = 75        ;How many frames the power-up stays on screen before disappearing
POWERUPCHANCE       = 128       ;255 is max, higher # = higher chance of spawning

INVINCIBILITYTIME   = 150
NOPCODE             = $00
DECHLCODE           = $35

SPEEDUPTIME         = 150
SPEEDDOWNTIME       = 150

CONTROLTIME         = 150

ARROWCHANGE         = 24

OBJECTSPEEDDOWNTIME = 200
OBJECTSPEEDUPTIME   = 200
OBJECTSPEEDCHANGE   = 5

STICKYTILETIME      = 75

TIMESTOPTIME        = 100
RETCODE             = $C9
JPCODE              = $C3
JPZCODE             = $CA
;
;Equates for title screen effect
;
tcos1           equ $9001
tcos2           equ $9002
tcos3           equ $9003
tcos4           equ $9004

cos1            equ $9101
cos2            equ $9102
cos3            equ $9103
cos4            equ $9104

ali_cosines     equ $8d00
ali_lvidbytes   equ $8e00
ali_dvidbytes   equ $8f00

picbuffer       equ $9400

im2table        equ $f800
intdest         equ $f9f9

#define msb(foo) (foo)/256
;
.org _asm_exec_ram

    nop
    jp ProgStart
    .dw 1
    .dw ShellTitle
    .dw DodgerIcon

ShellTitle:
    .db "Dodger v2.0 by Cullen Sauls",0
DodgerIcon:
 .db 8,1
 .db %00011000
 .db %00000100
 .db %00011100
 .db %00111110
 .db %00111110
 .db %00111110
 .db %00111110
 .db %00011100
;
;Writeback data, cannot be compressed
HighScoreTable:
 .db 38,30
 .db "--------",0
 .dw $0                     ;Score #1
 .db 46,30
 .db "--------",0
 .dw 0                      ;Score #2
 .db 54,30
 .db "--------",0
 .dw 0                      ;Score #3
HighScoreTableEnd:

ProgStart:
 call _runindicoff
 call _flushallmenus
 call _clrLCD

 res appTextSave,(iy+appflags)

 ld hl,$CA00+1018
 ld de,RandSeedSave
 ld bc,6
 ldir

 call InstallInt

 ld a,1
 ld (LevelSave),a
;Display Title Screen
 ld de,TitleScreen
 call decompV
 ld hl,SCREENADDR
 ld de,picbuffer
 ld bc,1024
 ldir
;
;Title screen effect by Aaron Curtis
;
;** align data to 256-byte boundaries **
 ld hl,cosines
 push hl
 ld de,ali_cosines
 ld bc,128
 ldir
 pop hl
 ld c,128+16
 ldir
 ld de,ali_dvidbytes
 ld c,16
 ldir
;** set up grayscale handler **
 di                                  ;if calc was already in im 2, it could crash w/out the di
 ld hl,im2table                      ;vector table starts here
 ld a,h
 ld i,a                              ;put table address in i
 ld b,1                              ;ld bc,256
 ld d,h                              ;put im2table+1 in de
 ld e,b
 ld (hl),msb(intdest)
 ldir                                ;table is 257 bytes
 ld d,(hl)
 ld e,(hl)                           ;ld de,intdest
 ld hl,intcode
 ld c,endintcode-intcode             ;intcode < 256 bytes
 ldir                                ;copy the interupt code to $e4e4
 im 2                                ;tell calc to use im 2
 ei
mainloop:
 halt
 call drawstuff
 call _get_key
 or a
 jr z,mainloop

 im 1
 ld a,$fc
 out (0),a

;LoopTilEnter:
; call _get_key
; cp K_ENTER             ;$09
; jr z,MainMenu
; cp K_SECOND            ;$36
; jr z,MainMenu
; jr LoopTilEnter
;
;End of Aaron Curtis' effect
;
MainMenu:
 call _ram_page_1
;
;Variable setup
;
 ld hl,VarSetupTable
 ld de,NumObjects
 ld bc,NUMSETUPVARS
 ldir
 ld a,(LevelSave)
 ld (Level),a

;Set FPS vars
#ifdef DEBUG_FPS
 xor a
 ld (InterruptCounter),a
 ld (FPS),a
 ld (DispFPS),a
#endif

;Call any functions that will revert anything that was self-modified
; during the game.
;Example: Invincibility makes you not take damage, and if you quit before
; the time for it runs out, you will be invincible in later games due to
; self-modification. Therefore, you must call the deactivate function here
; to make sure it does not carry over.
 call PUInvincibilityDeactivate+1
 call PUTimeStopDeactivate+1

 ld hl,(HighScoreTable+11)
 ld de,HighScoreNumStr+6
 ld b,5
 call WordToDec
 ld hl,(HighScoreTable+24)
 ld de,HighScoreNumStr+14
 ld b,5
 call WordToDec
 ld hl,(HighScoreTable+37)
 ld de,HighScoreNumStr+22
 ld b,5
 call WordToDec

 call _clrLCD

 ld hl,SCREENADDR+(16*8)
 ld de,SCREENADDR+(16*8)+1
 ld (hl),$FF
 ld bc,15
 ldir

 ld hl,MenuText
 call _PUTS
 call _PUTS
 ld b,4
 call _VPUTS
 djnz $-3
 ld hl,HighScoreTable
 ld b,3
 call _VPUTS
 inc hl
 inc hl
 djnz $-5

MenuLoop:
 call _get_key
 cp K_EXIT
 jp z,ExitProgram
 cp K_ENTER
 jr z,StartGame
 cp K_SECOND
 jr z,StartGame
 cp K_CLEAR
 jp z,ClearHighScores
 cp K_UP
 ld b,a
 call z,IncLevel
 ld a,b
 cp K_DOWN
 call z,DecLevel

 ld a,(Level)
 add a,'0'
 ld hl,$1102
 ld (_curRow),hl
 call _putc

 jr MenuLoop

StartGame:
 ld a,(Level)
 ld (LevelSave),a
 ld b,a
 ld a,-DELAYCHANGE
 add a,DELAYCHANGE
 djnz $-2
 ld b,a
 ld a,LEVEL1DELAY
 sub b
 ld (StartDelay),a

 ld hl,OBJECTADDR
 ld de,OBJECTADDR+1
 ld bc,8*255
 ld (hl),0
 ldir

 ld hl,PUADDR
 ld de,PUADDR+1
 ld bc,8*255
 ld (hl),0
 ldir

 ld hl,POINTSTACK
 ld de,POINTSTACK+1
 ld bc,255
 ld (hl),0
 ldir
;
;Gamescreen setup
;
 call _clrLCD

 ld hl,SCREENADDR
 ld de,16
 ld b,16
 ld (hl),$FF
 inc hl
 djnz $-3
 dec hl
 ld b,62
 add hl,de
 ld (hl),%00000001
 djnz $-3
 inc hl
 ld b,16
 ld (hl),$FF
 inc hl
 djnz $-3

 ld hl,SCREENADDR+16+13
 call MakeBlackSideLines
 ld hl,SCREENADDR+(16*16)+13
 call MakeBlackSideLines
 ld hl,SCREENADDR+(16*31)+13
 call MakeBlackSideLines
 ld hl,SCREENADDR+(16*46)+13
 call MakeBlackSideLines
 ld hl,SCREENADDR+(16*61)+13
 call MakeBlackSideLines
 ld hl,SCREENADDR+(16*62)+13
 call MakeBlackSideLines

 ld hl,LevelTxt
 ld b,8
 call _VPUTS
 djnz $-3
;
;Start game
;
MainLoop:
 ld hl,BUFFERADDR+16
 ld de,BUFFERADDR+17
 ld (hl),0
 ld bc,16*62-1
 ldir

 ld hl,BUFFERADDR+16
 ld de,16
 ld a,%10000000
 ld b,62
 ld (hl),a
 add hl,de
 djnz $-2

 ld hl,BUFFERADDR+28
 ld de,16
 rlca
 ld b,62
 ld (hl),a
 add hl,de
 djnz $-2
;
;Check for death
;
 ld a,(Life)
 or a
 jr nz,NotDead
 ld hl,DeathTimer
 dec (hl)
 ld a,(hl)
 or a
 jr nz,NoUpdateDeathFrame
 ld (hl),DEATHDELAY
 ld hl,DeathFrame
 inc (hl)
 ld a,(hl)
 cp NUMDEATHFRAME
 jp z,EndDeath
NoUpdateDeathFrame:
 ld hl,DeathFrame
 ld a,(hl)
 add a,a
 add a,a
 add a,a
 add a,a
 ld hl,ManDie1
 ADD_HL_A
 push hl
 ld hl,ManX
 ld b,(hl)
 inc hl
 ld c,(hl)
 pop hl
 call PutSpriteClip
 jp SkipNormalExecution
;
;Execute point stack code
;
NotDead:
 ld a,(NumPointStack)
 or a
TimeStopMod1 = $
 jp z,DonePSUpdate
 ld b,a
 ld hl,POINTSTACK-1
PSUpdateLoop:
 push bc
 inc hl
 ld a,(hl)
 or a
 jr z,$-3
 dec (hl)
 jr nz,NoPointsAdded
 push hl
 ld hl,NumPointStack
 dec (hl)
 ld hl,Avoid
 inc (hl)
 ld a,(Level)
 ld hl,(Score)
 ADD_HL_A
 ld (Score),hl
 ld a,(Avoid)
 ld b,0
 inc b
 sub LEVELUPAVOID
 jr c,NoLevelUp
 jr nz,$-5
 ld a,(Level)
 cp b
 jr nz,NoLevelUp
 ld hl,Level
 inc (hl)
 ld hl,StartDelay
 ld a,(hl)
LevelUpMod = $+1
 sub DELAYCHANGE
 ld (hl),a
 sub MINDELAY
 jr nc,$+5
 ld a,MINDELAY
 ld (hl),a

 ld hl,SCREENADDR
 call FlashScreen
 ld hl,SCREENADDR
 call FlashScreen

NoLevelUp:
 pop hl
NoPointsAdded:
 pop bc
 djnz PSUpdateLoop
DonePSUpdate:
;
;Execute Power-Up code
;
 ld hl,PUCoolDown
 ld a,(hl)
 or a
 jr z,$+3
 dec (hl)
 call z,SetPU
 ld a,(NumPU)
 or a
 jp z,DonePUUpdate
 ld b,a
 ld hl,PUADDR-6
PUUpdateLoop:
 push bc
 ld de,6
 add hl,de
 ld a,(hl)
 or a
 jr z,$-3
 push hl
 inc hl
 ld a,(hl)
 or a
 jr nz,PUIsActive

 inc hl
;Check collision of power-up
;Also save (B,C) coords for PutSprite
 ld a,(hl)
 ld b,a
 add a,4
 ld d,a
 inc hl
 ld a,(hl)
 ld c,a
 add a,4
 ld e,a
;HL -> Y Coord
 push bc
 push hl
 push hl
;Check if power-up has been on screen too long
 inc hl
 inc hl
 dec (hl)
 ld a,(hl)
 or a
 jr nz,$+13
 ld de,5
 sbc hl,de
 ld (hl),0
 ld hl,NumPU
 dec (hl)
;(D,E) = (X+4,Y+4) - 4 pixel offset makes the detection check the middle of power-up
 ld hl,ManX
 ld a,(hl)
 cp d
 jr nc,NoPickUp
 add a,7
 cp d
 jr c,NoPickUp
 inc hl
 ld a,(hl)
 cp e
 jr nc,NoPickUp
 add a,7
 cp e
 jr c,NoPickUp
 pop hl
 dec hl
 dec hl
 ld (hl),1
;HL -> Active
 ld de,PUReturn
 push de
 inc hl
 inc hl
 inc hl
 ld e,l
 ld d,h
 inc de
;DE -> Time
 ld a,(hl)
 add a,a
 ld hl,PowerUpActivateTable
 ADD_HL_A
 ld a,(hl)
 inc hl
 ld h,(hl)
 ld l,a
 jp (hl)
NoPickUp:
 pop hl
PUReturn:
 pop hl
 pop bc
 inc hl
 ld l,(hl)
 ld h,0
 add hl,hl
 add hl,hl
 add hl,hl
 add hl,hl
 ld de,PUSprites
 add hl,de
 call PutSpriteClip
 pop hl
 pop bc
 djnz PUUpdateLoop
 jr DonePUUpdate
PUIsActive:
 ld de,PUNoDeactivate
 push de
;HL -> Active
 ld e,l
 ld d,h
;DE -> Active
 ld bc,4
 add hl,bc
 dec (hl)
 ld a,(hl)
 or a
 ret nz
 dec hl
 ld a,(hl)
 add a,a
 ld hl,PowerUpDeactivateTable
 ADD_HL_A
 ld a,(hl)
 inc hl
 ld h,(hl)
 ld l,a
 ld a,(NumPU)
 dec a
 ld (NumPU),a
 jp (hl)
PUNoDeactivate:
 pop hl
 pop bc
 dec b
 jp nz,PUUpdateLoop

DonePUUpdate:
;
;Execute object updating code
;
 ld hl,CurDelay
TimeStopMod2 = $
 dec (hl)
 ld a,(hl)
 or a
 call z,SetNewObject
 ld a,(NumObjects)
 or a
 jp z,DoneObjectUpdate

;Build object table
 ld b,a
 push bc
 ld c,-1
 ld ix,OBJECTTABLE
 ld hl,OBJECTADDR-8
 ld de,8
BuildTableLoop:
 inc c
 add hl,de
 ld a,(hl)
 or a
 jr z,BuildTableLoop
 ld (ix),c
 inc ix
 djnz BuildTableLoop

 pop bc
 ld hl,OBJECTTABLE
ObjectUpdateLoop:
 push bc

 push hl
 ld l,(hl)
 ld h,0
 ld de,OBJECTADDR
 add hl,hl
 add hl,hl
 add hl,hl
 add hl,de

 ld a,(hl)
#ifdef NODAMAGEOBJECTS
 push hl
#endif
 inc hl
 push hl
 ld de,UOLReturn
 push de
TimeStopMod3 = $
 nop
;
 ld e,l
 ld d,h
;
 ld l,(hl)
 ld h,a
 jp (hl)
UOLReturn:
 pop hl
 inc hl
;Check collision of object
;Also save (B,C) coords for PutSprite
 ld a,(hl)
 ld b,a
 add a,20
 ld d,a
 inc hl
 ld a,(hl)
 ld c,a
 add a,20
 ld e,a

#ifdef NODAMAGEOBJECTS
 pop hl
 push de
 push bc
;HL -> First byte of object
 xor a
 ld (NoDmgMod),a
 ld de,ObjectNoDamageTable
 ld b,NUMNODAMAGEOBJECTS
CheckNoDamageTableLoop:
 push hl
 ld a,(hl)
 inc hl
 ld l,(hl)
 ld h,a
 ex de,hl
;HL = Current position in table
;DE = Object update function address
 ld a,(hl)
 inc hl
 push hl
 ld h,(hl)
 ld l,a
;HL = Update function in table 
 or a
 sbc hl,de
 pop de
 jr nz,$+7
 ld a,NoCollision-(NoDmgMod)-1
 ld (NoDmgMod),a
 inc de
 pop hl
 djnz CheckNoDamageTableLoop
 pop bc
 inc hl
 inc hl
 inc hl
 pop de
#endif

 push hl

#ifdef NODAMAGEOBJECTS
NoDmgMod = $+1
 jr $+2
#endif

;(D,E) = (X+20,Y+20) - 16 pixel offset makes sure objects are on screen.
;                    - 4 pixel offset makes the detection check the middle of the object
 ld hl,ManX
 ld a,(hl)
 add a,16
 cp d
 jr nc,NoCollision
 add a,7
 cp d
 jr c,NoCollision
 inc hl
 ld a,(hl)
 add a,16
 cp e
 jr nc,NoCollision
 add a,7
 cp e
 jr c,NoCollision
 ld hl,Life
 ld a,(hl)
 or a
 jr z,$+3
DmgMod1 = $
 dec (hl)
NoCollision:
 pop hl
;
 inc hl
 ld a,(hl)
 inc hl
 ld h,(hl)
 ld l,a
 call PutSpriteClip
 pop hl
 inc hl
 pop bc
 dec b
 jp nz,ObjectUpdateLoop
; djnz ObjectUpdateLoop

DoneObjectUpdate:
 xor a
 ld (ManMove),a

 ld a,%01111110
 out (1),a
 in a,(1)
 rra
 push af
KeyModDown = $+1
 call nc,MoveManDown
 pop af
 rra
 push af
KeyModLeft = $+1
 call nc,MoveManLeft
 pop af
 rra
 push af
KeyModRight = $+1
 call nc,MoveManRight
 pop af
 rra
KeyModUp = $+1
 call nc,MoveManUp

 ld a,%00111111
 out (1),a
 in a,(1)
 rla
 call nc,PauseGame
 rla
 jp nc,ExitGame
; rla
; jr nc,DoAction
 ld a,(ManMove)
 or a
 jr nz,ManMoved

 ld hl,NoMoveTimer
 inc (hl)
 ld a,(hl)
 cp NOMOVETIME
 jr c,NoStandStillDamage
 ld hl,NoMoveDelay
 inc (hl)
 ld a,(hl)
 cp NOMOVEDELAY
 jr c,NoStandStillDamage
 ld (hl),0
 ld hl,Life
 ld a,(hl)
 or a
 jr z,$+3
DmgMod2 = $
 dec (hl)
NoStandStillDamage:

 ld a,MOVEANIMTIME
 ld (MoveAnimTimer),a
 ld a,1
 ld (MoveAnimFrame),a

 ld hl,ManX
 ld b,(hl)
 inc hl
 ld c,(hl)
 ld hl,ManStand
 call PutSpriteClip
 jr ManMoved+4

ManMoved:
 xor a
 ld hl,NoMoveTimer
 ld (hl),a
 inc hl
 ld (hl),a
;
;Copy buffer to screen
;
SkipNormalExecution:
 ld hl,BUFFERADDR+16
 ld de,SCREENADDR+16
 ld c,62
 ld b,13
 ld a,(hl)
 ld (de),a
 inc hl
 inc de
 djnz $-4
 inc hl
 inc hl
 inc hl
 inc de
 inc de
 inc de
 dec c
 jr nz,$-15

 ld de,LNumStr+3
 ld a,(Level)
 ld b,2
 call ByteToDec

 ld de,SNumStr+6
 ld hl,(Score)
 ld b,5
 call WordToDec

 ld de,ANumStr+4
 ld a,(Avoid)
 ld b,3
 call ByteToDec


 ld de,LiNumStr+3
 ld a,(Life)
 ld b,2
 call ByteToDec

 ld hl,LNumStr
 ld b,4
 call _VPUTS
 djnz $-3

;Delay to try and keep speed constant
 ld b,0
 ld a,(NumObjects)
 ld c,a
 ld a,128
 sub c
 sub 75
 inc b
 jr nc,$-3
 HALT_LOOP

#ifdef DEBUG_FPS
DisplayFPS:
 ld hl,FPS
 inc (hl)
 inc hl
 ld a,(hl)
 or a
 jr z,EndFPSDisp
 ld (hl),0
 dec hl
 ld a,(hl)
 ld (hl),0
 dec a
 ld b,2
 ld de,FPSNumStr+3
 call ByteToDec
 dec de
 ex de,hl
 call _VPUTS
EndFPSDisp:
#endif

 jp MainLoop

ExitGame:
 ld b,30
 HALT_LOOP
EndDeath:
 ld de,(Score)
 ld hl,(HighScoreTable+11)
 call _cphlde
 jr nc,CheckSecondPlace
 ld hl,HighScoreTable+2
 push hl
 ld hl,HighScoreTable+15
 ld de,HighScoreTable+28
 ld bc,11
 ldir
 ld hl,HighScoreTable+2
 ld de,HighScoreTable+15
 ld bc,11
 ldir
 jr NewHighScore
CheckSecondPlace:
 ld hl,(HighScoreTable+24)
 call _cphlde
 jr nc,CheckThirdPlace
 ld hl,HighScoreTable+15
 push hl
 ld hl,HighScoreTable+15
 ld de,HighScoreTable+28
 ld bc,11
 ldir
 jr NewHighScore
CheckThirdPlace:
 ld hl,(HighScoreTable+37)
 call _cphlde
 jp nc,MainMenu
 ld hl,HighScoreTable+28
 push hl
NewHighScore:
 pop de
;
;High score has been beaten, get new name
;DE -> Name in High Score Table to replace
;
 push de
 ld a,' '
 ld hl,_textShadow+111
 ld (hl),a
 ld b,8
 ld (de),a
 inc de
 djnz $-2
 inc de
 ex de,hl
 ld de,(Score)
 ld (hl),e
 inc hl
 ld (hl),d

 call _clrLCD
 ld hl,NewHSText
 call _PUTS
 call _PUTS
 pop de
 ld hl,$0605
 ld (_curRow),hl
 ld a,' '
 ld (_curUnder),a
 call _putc
 ld (_curRow),hl
 call _cursorOn

 set appTextSave,(iy+appflags)
;
;repeat until [Enter] is pressed
;
GetNameLoop:
 push de
 call _get_key
 pop de
 cp K_ENTER
 jr z,SaveTable
 cp K_DEL
 jr z,DeleteChar

 cp K_SIGN
 jr z,SetSpace

 ld hl,KeyLetterTable
 ld bc,27
 cpir

 ld a,c
 or a
 jr z,GetNameLoop

 ld a,(de)
 or a
 jr z,GetNameLoop

 push de
 ld de,KeyLetterTable
 sbc hl,de
 ld a,l
 add a,'A'-1
 pop de
 ld (de),a
 inc de
 call _putc
CheckForMaxChar:
 ld a,(de)
 or a
 jr z,MaxCharInput
 ld a,' '
 jr EndGetNameLoop
MaxCharInput:
 ld a,$E7
EndGetNameLoop:
 ld (_curUnder),a
; ld (_textShadow+120),a
 call _putc
 ld hl,_curCol
 dec (hl)
 jr GetNameLoop

SetSpace:
 ld a,(de)
 or a
 jr z,GetNameLoop
 ld a,' '
 ld (de),a
 inc de
 call _putc
 jr CheckForMaxChar
DeleteChar:
 dec de
 ld a,(de)
 inc de
 cp 30
 jr z,GetNameLoop
 dec de
 ld a,' '
 ld (de),a
 call _cursorOff
 ld hl,_curCol
 call _putc
 dec (hl)
 dec (hl)
 call _putc
 dec (hl)
 call _cursorOn
 jr GetNameLoop
;
SaveTable:
 call _cursorOff
 res appTextSave,(iy+appflags)
;
;Writeback routine
; Taken from Jimmy Mardell (any program, he uses the same in all :)
;
 ld hl,_asapvar
 rst 20h
 rst 10h
 ex de,hl
 ld a,b
 ld de,HighScoreTable-$D748+4
 add hl,de
 adc a,0
 ld de,HighScoreTable
 ld b,HighScoreTableEnd-HighScoreTable
RepCopy:
 push af
 push hl
 call $46C3
 ld a,(de)
 ld (hl),a
 pop hl
 pop af
 call $4637
 inc de
 djnz RepCopy

 jp MainMenu
;
ExitProgram:
 call _clrLCD
 ld hl,_textShadow
 ld de,_textShadow+1
 ld (hl),' '
 ld bc,128
 ldir
;Clear the screen so that weird characters do not show.
 res onInterrupt,(IY+onflags)
 set graphdraw,(IY+graphflags)
;Set flags to clean graph and so that the user does not get
; an ON error on exit.
 set appTextSave,(iy+appflags)
;Make text save to text shadow again.
 ld hl,RandSeedSave
 ld de,$CA00+1018
 ld bc,6
 ldir
;Restore random seed
 ld hl,_asapvar
 ld (hl),0
;Force the program to be reloaded into memory on next execution.
 call UninstallInt
;Take out user interrupt
 jp _homeup
;
;Sub Routines
;
;Routines for title screen effect by Aaron Curtis
drawstuff:
 ld hl,picbuffer
 ld c,64
 ld de,cos3
 call restorebytes
vloop:
 ld b,16
 ld de,cos1
 call restorebytes
hloop:
 push hl
 ld d,msb(ali_cosines)
 ld hl,tcos4
 xor a
addloop:
 ld e,(hl)
 ex de,hl
 add a,(hl)
 ex de,hl
 dec l
 jr nz,addloop
 inc (hl)
 inc l
 inc (hl)
 inc (hl)
 ld h,msb(ali_lvidbytes)
 rrca
 rrca
 rrca
 rrca
 and %00001111
 ld l,a
 ld a,(hl)
 inc h
 ld d,(hl)
 pop hl
 push hl
 ld e,(hl)
 set 5,h
 set 6,h
; and e
 xor e
 ld (hl),a
 set 3,h
 ld a,d
; and e
 xor e
 ld (hl),a
 pop hl
 inc hl
 djnz hloop
 ex de,hl
 ld hl,tcos3
 inc (hl)
 inc (hl)
 inc (hl)
 inc l
 ld a,(hl)
 add a,4
 ld (hl),a
 ex de,hl
 dec c
 jr nz,vloop
 ld hl,cos1
 inc (hl)
 inc l
 dec (hl)
 dec (hl)
 inc l
 inc (hl)
 inc (hl)
 inc (hl)
 inc l
 ld a,(hl)
 sub 4
 ld (hl),a
 ret
restorebytes:
 ld a,(de)
 dec d
 ld (de),a
 inc d
 inc e
 ld a,(de)
 dec d
 ld (de),a
 ret
;**********************
;** interupt routine **
;**********************
intcode:
 ex af,af'
 exx
 in a,(3)
; bit 1,a           ;I modified, saved 1 byte :)
 and %10
 jr z,norefresh
 call _scan_code
 ld a,$f4
 srl c
 jr nz,cnotzero
 ld c,%00000110
cnotzero:                           
 jr nc,nopageflip
 ld a,$fc
nopageflip:
 out (0),a
norefresh:
 ld a,%00001000
 out (3),a
 ld a,%00001011
 out (3),a
 ex af,af'
 exx
 ei
 ret
endintcode:
;
;End of Aaron's routines
;
IncLevel:
 ld hl,Level
 inc (hl)
 ld a,(hl)
 cp 10
 ret nz
 ld (hl),1
 ret
DecLevel:
 ld hl,Level
 dec (hl)
 ld a,(hl)
 or a
 ret nz
 ld (hl),9
 ret
ClearHighScores:
 ld hl,HighScoreTableRestore
 ld de,HighScoreTable+2
 ld bc,37
 ldir
 jp SaveTable
;
MoveManUp:
 ld hl,ManY
 ld a,(ManSpeed)
 ld b,a
 ld a,(hl)
 sub b
#ifndef BOUND_IS_ONE
 sub UPBOUND
#else
 dec a
#endif
 cp 200
 ret nc
 add a,UPBOUND
 ld (hl),a
 ld hl,ManUpDown1
 ld a,(MoveAnimFrame)
 dec a
 jr z,EndMoveUpdate
 ld hl,ManUpDown2
 jr EndMoveUpdate
MoveManDown:
 ld hl,ManY
 ld a,(ManSpeed)
 add a,(hl)
 cp DOWNBOUND
 ret nc
 ld (hl),a
 ld hl,ManUpDown1
 ld a,(MoveAnimFrame)
 dec a
 jr z,EndMoveUpdate
 ld hl,ManUpDown2
 jr EndMoveUpdate
MoveManLeft:
 ld hl,ManX
 ld a,(ManSpeed)
 ld b,a
 ld a,(hl)
 sub b
#ifndef BOUND_IS_ONE
 sub LEFTBOUND
#else
 dec a
#endif
 cp 200
 ret nc
 add a,LEFTBOUND
 ld (hl),a
 ld hl,ManLeft1
 ld a,(MoveAnimFrame)
 dec a
 jr z,EndMoveUpdate
 ld hl,ManLeft2
 jr EndMoveUpdate
MoveManRight:
 ld hl,ManX
 ld a,(ManSpeed)
 add a,(hl)
 cp RIGHTBOUND
 ret nc
 ld (hl),a
 ld hl,ManRight1
 ld a,(MoveAnimFrame)
 dec a
 jr z,EndMoveUpdate
 ld hl,ManRight2
EndMoveUpdate:
 push hl
 ld a,1
 ld (ManMove),a
 ld hl,MoveAnimTimer
 dec (hl)
 ld a,(hl)
 or a
 jr nz,NoMoveAnimFrameChange
 ld (hl),MOVEANIMTIME
 ld hl,MoveAnimFrame
 ld a,(hl)
 cpl
 inc a
 ld (hl),a
NoMoveAnimFrameChange:
 ld hl,ManX
 ld b,(hl)
 inc hl
 ld c,(hl)
 pop hl
 jp PutSpriteClip
;
PauseGame:
 push af
 call _get_key
 ld hl,PauseText
 call _PUTS
PGLoop:
 in a,(3)
 bit 3,a                        ;check the [ON] key bit
 call z,TurnOffCalc             ;[ON] key was pressed
 call _get_key
 cp K_PLUS
 call z,ContrastUp
 cp K_MINUS
 call z,ContrastDown
 or a
 jr z,PGLoop
 ld b,25
 HALT_LOOP
 pop af
 ret
TurnOffCalc:
 ld a,1
 out (3),a
 halt
 ld a,11
 out (3),a
LoopTilOn:
 halt
 in a,(3)
 bit 3,a                        ;check the [ON] key bit
 jr z,LoopTilOn                ;[ON] still being detected
 ret
;
SetNewObject:
 ld a,(StartDelay)
 ld (CurDelay),a
GetObjectNum:
 call RandomNumber
 and OBJECTAND
 cp NUMOBJECTS
 jr nc,GetObjectNum

 add a,a
 ld hl,ObjectCreateTable
 ADD_HL_A
 ld a,(hl)
 inc hl
 ld h,(hl)
 ld l,a
 jp (hl)
;
;Power-Up setting routine
;
SetPU:
 ld hl,PUCoolDown
 ld (hl),PUDELAY

 call RandomNumber
 cp POWERUPCHANCE
 ret nc
;Power-up is to be placed
 ld hl,PUADDR-6
 ld de,6
 add hl,de
 ld a,(hl)
 or a
 jr nz,$-3
;HL -> Start of PU Object to create
 ld (hl),1
 inc hl
 ld (hl),0
 inc hl

 call RandomNumber
 cp 93
 jr nc,$-5
 add a,2
 ld (hl),a
 inc hl
 call RandomNumber
 cp 53
 jr nc,$-5
 add a,2
 ld (hl),a
 inc hl

GetPowerUpNum:
 call RandomNumber
 and POWERUPAND
 cp NUMPOWERUP
 jr nc,GetPowerUpNum

 ld (hl),a
 inc hl
 ld (hl),POWERUPTIME

 ld hl,NumPU
 inc (hl)

 ret
;
;Universal
;
MakeBlackSideLines:
 ld a,$FF
 ld (hl),a
 inc hl
 ld (hl),a
 inc hl
 ld (hl),a
 ret
;
;Inverts the screen passed to it
;Input:
;   HL -> Screen to invert
;
FlashScreen:
 ld de,1024
 ld a,(hl)
 cpl
 ld (hl),a
 inc hl
 dec de
 ld a,d
 or e
 jr nz,$-7
 ret
;===========================================
; RandomNumber     [Assembly Coder's Zenith]
; out: A = psuedo random number
; modified: AF, BC    (14 bytes/62 t-states)
;===========================================
RandomNumber:
 ld a,r
 ld b,a
 ld a,($1234)
_@RandomNumberSeed =$-2
 ld c,a
 ld a,(bc)
 ld (_@RandomNumberSeed),a
 xor b
 sub b
 add a,c
 ret
;
;Takes a number and inserts it into a string in decimal format.
;
;Input: A = Number
;       B = Number of digits
;       DE -> End of number in string
;
;Output: String has number placed in
;        DE -> Start of number in string - 1
;        B = 0
;        A,HL  Destroyed
;
ByteToDec:
 ld l,a
 ld h,0
WordToDec:
NTDLoop:
 call _divHLby10
 add a,'0'
 ld (de),a
 dec de
 djnz NTDLoop
 ret
;
;Adds a point count-down timer to the stack
;Input:
; B = Number of frames to wait until points are added
;Output:
; Point stack size increased by 1
; Points delay added to stack
AddPointStack
 ld hl,NumPointStack
 inc (hl)
 ld hl,POINTSTACK-1
 inc hl
 ld a,(hl)
 or a
 jr nz,$-3
 ld (hl),b
 ret
;
;Creates a new object, sets Spares to 0
;Input:
; (B,C) = (X,Y)
; DE->Update Function
; HL->Sprite for object
;Output:
; New object created, spare bytes set to zero
; HL->Last byte of new object
;All registers but BC destroyed
CreateObject:
 push hl
 ld hl,NumObjects
 ld a,(hl)
 cp $FF
 jr nz,$+4
 pop hl
 ret
 inc (hl)
 push de
 ld hl,OBJECTADDR-8
 ld de,8
 add hl,de
 ld a,(hl)
 or a
 jr nz,$-3
 pop de
 ld (hl),d
 inc hl
 ld (hl),e
 inc hl
 ld (hl),b
 inc hl
 ld (hl),c
 inc hl
 pop de
 ld (hl),e
 inc hl
 ld (hl),d
 xor a
 inc hl
 ld (hl),a
 inc hl
 ld (hl),a
 ret
;Deletes an object and decrements NumObjects
;Input:
; HL->Starting byte of object to delete
;Output:
; Number of objects reduced by 1
DeleteObject:
 ld (hl),0
 ld hl,NumObjects
 dec (hl)
 ret
;
;Strings
;
LevelTxt:
 .db 2,106
 .db "Level",0
ScoreTxt:
 .db 17,106
 .db "Score",0
AvoidTxt:
 .db 32,106
 .db "Avoid",0
LifeTxt:
 .db 47,106
 .db "Life",0
LNumStr:
 .db 9,106
 .db "00",0
SNumStr:
 .db 24,106
 .db "00000",0
ANumStr:
 .db 39,106
 .db "000",0
LiNumStr:
 .db 54,106
 .db "00",0
NewHSText:
 .db 0,2
 .db "A New High Score!",0
 .db 2,3
 .db "Enter your name",0
PauseText:
 .db 3,2
 .db $DB,"Game Paused",$DA,0
MenuText:
 .db 0,5
 .db "D o d g e r",0
 .db 2,3
 .db "Level (",$06,"/",$07,"):",0
 .db 29,44
 .db "High-Scores",0
HighScoreNumStr:
 .db 38,79
 .db "-----",0
 .db 46,79
 .db "-----",0
 .db 54,79
 .db "-----",0
;
;Data
;
HighScoreTableRestore:
 .db "--------",0
 .dw $0                     ;Score #1
 .db 46,30
 .db "--------",0
 .dw 0                      ;Score #2
 .db 54,30
 .db "--------",0
 .dw 0                      ;Score #3
;
KeyLetterTable:
 .db $2E,$26,$1E,$16,$0E
 .db $2D,$25,$1D,$15,$0D
 .db $2C,$24,$1C,$14,$0C
 .db $2B,$23,$1B,$13,$0B
 .db     $22,$1A,$12,$0A
 .db     $21,$19
;
#ifdef DEBUG_FPS
FPSNumStr:
 .db 54, 118
 .db "00",0
#endif
;
VarSetupTable:                        ;speed
 .db 0,48,28,LEVEL1DELAY/2,LEVEL1DELAY,1,0,0,0,50,2,0,PUDELAY,0,DEATHDELAY,0,0,1,0,0,0
ShrapnelUpdateData:
 .db 0,-3,2,-2,3,0,2,2,0,3,-2,2,-3,0,-2,-2
ObjectCreateTable:
 .dw CreateBomb
 .dw CreateSpark
 .dw CreateHomingMissile
 .dw CreateBlackHole
 .dw CreateRepel
 .dw CreateBounceball
 .dw CreateRicochet
 .dw CreateOrbOfDeath
 .dw CreateGhost
ObjectNoDamageTable:
;Define update functions for objects that will not do damage
;Format: .dw UPDATE_FUNCTION_NAME
PowerUpActivateTable:
 .dw PULifeUpActivate
 .dw PULifeDownActivate
 .dw PUInvincibilityActivate
 .dw PUSpeedUpActivate
 .dw PUSpeedDownActivate
 .dw PUControlActivate
 .dw PUClearActivate
 .dw PUArrowUpActivate
 .dw PUArrowDownActivate
 .dw PUArrowLeftActivate
 .dw PUArrowRightActivate
 .dw PUObjectSpawnDownActivate
 .dw PUObjectSpawnUpActivate
 .dw PUStickyTileActivate
 .dw PUTimeStopActivate
PowerUpDeactivateTable:
 .dw PULifeUpDeactivate
 .dw PULifeDownDeactivate
 .dw PUInvincibilityDeactivate
 .dw PUSpeedUpDeactivate
 .dw PUSpeedDownDeactivate
 .dw PUControlDeactivate
 .dw PUClearDeactivate
 .dw PUArrowUpDeactivate
 .dw PUArrowDownDeactivate
 .dw PUArrowLeftDeactivate
 .dw PUArrowRightDeactivate
 .dw PUObjectSpawnDownDeactivate
 .dw PUObjectSpawnUpDeactivate
 .dw PUStickyTileDeactivate
 .dw PUTimeStopDeactivate
;
;Sprites
;
ManStand:
 .db %00011000
 .db %00100100
 .db %00011000
 .db %00111100
 .db %01011010
 .db %00011000
 .db %00100100
 .db %00100100
 .db %00011000
 .db %00111100
 .db %00011000
 .db %00111100
 .db %01011010
 .db %00011000
 .db %00100100
 .db %00100100
;
ManUpDown1:
 .db %00011000
 .db %00100100
 .db %00011000
 .db %00111100
 .db %01011010
 .db %00011000
 .db %00100100
 .db %00000100
 .db %00011000
 .db %00111100
 .db %00011000
 .db %00111100
 .db %01011010
 .db %00011000
 .db %00100100
 .db %00000100
;
ManUpDown2:
 .db %00011000
 .db %00100100
 .db %00011000
 .db %00111100
 .db %01011010
 .db %00011000
 .db %00100100
 .db %00100000
 .db %00011000
 .db %00111100
 .db %00011000
 .db %00111100
 .db %01011010
 .db %00011000
 .db %00100100
 .db %00100000
;
ManLeft1:
 .db %00011000
 .db %00100100
 .db %00011000
 .db %00111110
 .db %00011000
 .db %00011110
 .db %00010010
 .db %00110000
 .db %00011000
 .db %00111100
 .db %00011000
 .db %00111110
 .db %00011000
 .db %00011110
 .db %00010010
 .db %00110000
;
ManLeft2:
 .db %00011000
 .db %00100100
 .db %00011000
 .db %00011100
 .db %00111010
 .db %00011000
 .db %00001100
 .db %00011100
 .db %00011000
 .db %00111100
 .db %00011000
 .db %00011100
 .db %00111010
 .db %00011000
 .db %00001100
 .db %00011100
;
ManRight1:
 .db %00011000
 .db %00100100
 .db %00011000
 .db %01111100
 .db %00011000
 .db %01111000
 .db %01001000
 .db %00001100
 .db %00011000
 .db %00111100
 .db %00011000
 .db %01111100
 .db %00011000
 .db %01111000
 .db %01001000
 .db %00001100
;
ManRight2:
 .db %00011000
 .db %00100100
 .db %00011000
 .db %00111000
 .db %01011100
 .db %00011000
 .db %00110000
 .db %00111000
 .db %00011000
 .db %00111100
 .db %00011000
 .db %00111000
 .db %01011100
 .db %00011000
 .db %00110000
 .db %00111000
;
ManDie1:
 .db %01000010
 .db %00101100
 .db %00110100
 .db %01101110
 .db %01110110
 .db %00101100
 .db %00110100
 .db %01000010
 .db %01000010
 .db %00101100
 .db %00110100
 .db %01101110
 .db %01110110
 .db %00101100
 .db %00110100
 .db %01000010
;
ManDie2:
 .db %00010100
 .db %01000000
 .db %00101000
 .db %00000010
 .db %01010001
 .db %00000100
 .db %10010010
 .db %01000100
 .db %00010100
 .db %01000000
 .db %00101000
 .db %00000010
 .db %01010001
 .db %00000100
 .db %10010010
 .db %01000100
;
ManDie3:
 .db %00000000
 .db %00000000
 .db %00000000
 .db %00000000
 .db %00000000
 .db %00000000
 .db %01011010
 .db %11111111
 .db %00000000
 .db %00000000
 .db %00000000
 .db %00000000
 .db %00000000
 .db %00000000
 .db %01011010
 .db %11111111
;
TitleScreen:
 .db $B7,$00,$CF,$B7,$07,$13,$B7,$00,$2D,$F8,$FC,$FE,$B7,$9E,$0D,$FE
 .db $FE,$FC,$B7,$00,$06,$08,$08,$0E,$09,$09,$09,$0E,$B7,$00,$23,$0F
 .db $1F,$1F,$B7,$3C,$0A,$3F,$1F,$0F,$B7,$00,$08,$44,$28,$28,$28,$10
 .db $10,$20,$B7,$00,$21,$81,$E3,$B7,$F3,$0B,$E3,$E3,$C1,$B7,$00,$06
 .db $70,$88,$82,$82,$82,$8A,$71,$B7,$00,$20,$0F,$0F,$0F,$EF,$FF,$FF
 .db $B7,$CF,$0A,$FF,$FF,$EF,$B7,$00,$06,$14,$14,$54,$55,$55,$55,$D4
 .db $B7,$00,$23,$1E,$3F,$3F,$B7,$3C,$07,$3F,$3F,$1E,$00,$3C,$3F,$1F
 .db $0F,$B7,$00,$06,$CE,$29,$E9,$09,$E9,$B7,$00,$23,$F0,$F1,$B7,$F3
 .db $0C,$F1,$F0,$E0,$C0,$B7,$00,$04,$03,$04,$04,$03,$00,$04,$03,$B7
 .db $00,$23,$F8,$FE,$FE,$CF,$CF,$FF,$FF,$FF,$C0,$B7,$CF,$04,$FE,$FE
 .db $7C,$B7,$00,$07,$80,$3D,$05,$9D,$A5,$3C,$B7,$00,$23,$3D,$3F,$3F
 .db $3F,$3E,$B7,$3C,$0B,$B7,$00,$06,$08,$08,$29,$2A,$29,$28,$EB,$B7
 .db $00,$23,$B7,$80,$04,$B7,$00,$14,$C0,$00,$80,$40,$80,$B7,$00,$D2
;
;******************
;** cosine table **
;******************
cosines:
    .db 64, 64, 64, 64, 63, 63, 63, 62
    .db 62, 61, 60, 59, 59, 58, 57, 56
    .db 55, 53, 52, 51, 50, 48, 47, 46
    .db 44, 43, 41, 40, 38, 37, 35, 34
    .db 32, 30, 29, 27, 26, 24, 23, 21
    .db 20, 18, 17, 16, 14, 13, 12, 11
    .db 9,  8,  7,  6,  5,  5,  4,  3
    .db 2,  2,  1,  1,  1,  0,  0,  0
    .db 0,  0,  0,  0,  1,  1,  1,  2
    .db 2,  3,  4,  5,  5,  6,  7,  8
    .db 9,  11, 12, 13, 14, 16, 17, 18
    .db 20, 21, 23, 24, 26, 27, 29, 30
    .db 32, 34, 35, 37, 38, 40, 41, 43
    .db 44, 46, 47, 48, 50, 51, 52, 53
    .db 55, 56, 57, 58, 59, 59, 60, 61
    .db 62, 62, 63, 63, 63, 64, 64, 64
videobytes:
    ;* light *
    .db %00000000
    .db %10001000
    .db %01010101
    .db %01110111
    .db %00100010
    .db %01010101
    .db %10111011
    .db %11111111

    .db %11111111
    .db %11101110
    .db %01010101
    .db %10001000
    .db %11011101
    .db %01010101
    .db %00100010
    .db %00000000
    ;* dark *
    .db %00000000
    .db %00000000
    .db %00000000
    .db %10001000
    .db %11111111
    .db %11111111
    .db %11111111
    .db %11111111

    .db %11111111
    .db %11111111
    .db %11111111
    .db %11111111
    .db %00100010
    .db %00000000
    .db %00000000

#include "DodgerObj.h"
#include "DodgerPU.h"
#include "DodgerPS.h"
#include "Contrast.h"
#include "DispStr.h"
#include "VDecomp.h"
#include "UserInt.h"

.end
