;---------------------------------------
;
; Dodger include file
;
; Contains all data and code used for
;  objects in Dodger
;
; The main engine code does not need to
;  be changed when new objects are added.
;  However, you must update 2 constants
;  in the main file, and (possibly) add
;  labels if you want to modify something
;  in the engine (see invincibility and
;  control-swap power-ups).
;
;---------------------------------------
;
;Obstacle Creators
;
;Bomb that will explode
;First spare byte: Bomb delay time
;Second spare byte: Not used
CreateBomb:
 ld b,BOMBPOINTDELAY
 call AddPointStack
 call RandomNumber
 cp RIGHTBOUND-2
 jr nc,$-5
 add a,2
 ld d,a
 call RandomNumber
 cp DOWNBOUND-2
 jr nc,$-5
 ld b,d
 add a,2
 ld c,a
 ld de,BombUpdateFunction
 ld hl,Bomb1
 jp CreateObject
;Many sparks coming vertically or horizontally, leaves 1 row/column safe
;First spare byte: X modification
;Second spare byte: Y modification
CreateSpark:
 ld b,SPARKPOINTDELAY
 call AddPointStack
 call RandomNumber
 and %00000010
 jr z,SetSparkVert
 call RandomNumber
 cp DOWNBOUND-2
 jr nc,$-5
 add a,2
 push af
CSHorizLoop1:
 sub 10
 jr c,EndCSHorizLoop1
 ld c,a
 ld b,-7
 ld de,BasicObjectUpdateFunction1
 ld hl,Spark1
 push af
 call CreateObject
 pop af
 ld (hl),0
 dec hl
 ld (hl),SPARKSPEED
 sub 10
 jr c,EndCSHorizLoop1
 ld c,a
 ld b,RIGHTEDGE
 ld de,BasicObjectUpdateFunction1
 ld hl,Spark1
 push af
 call CreateObject
 pop af
 ld (hl),0
 dec hl
 ld (hl),-SPARKSPEED
 jr CSHorizLoop1
EndCSHorizLoop1:
 pop af
CSHorizLoop2:
 add a,10
 cp DOWNBOUND
 ret nc
 ld c,a
 ld b,RIGHTEDGE
 ld de,BasicObjectUpdateFunction1
 ld hl,Spark1
 push af
 call CreateObject
 pop af
 ld (hl),0
 dec hl
 ld (hl),-SPARKSPEED
 add a,10
 cp DOWNBOUND
 ret nc
 ld c,a
 ld b,-7
 ld de,BasicObjectUpdateFunction1
 ld hl,Spark1
 push af
 call CreateObject
 pop af
 ld (hl),0
 dec hl
 ld (hl),SPARKSPEED
 jr CSHorizLoop2
 ret
SetSparkVert:
 call RandomNumber
 cp RIGHTBOUND-2
 jr nc,$-5
 add a,2
 push af
CSVertLoop1:
 sub 10
 jr c,EndCSVertLoop1
 ld b,a
 ld c,-7
 ld de,BasicObjectUpdateFunction1
 ld hl,Spark2
 push af
 call CreateObject
 pop af
 ld (hl),SPARKSPEED
 dec hl
 ld (hl),0
 sub 10
 jr c,EndCSVertLoop1
 ld b,a
 ld c,64
 ld de,BasicObjectUpdateFunction1
 ld hl,Spark2
 push af
 call CreateObject
 pop af
 ld (hl),-SPARKSPEED
 dec hl
 ld (hl),0
 jr CSVertLoop1
EndCSVertLoop1:
 pop af
CSVertLoop2:
 add a,10
 cp RIGHTBOUND
 ret nc
 ld b,a
 ld c,64
 ld de,BasicObjectUpdateFunction1
 ld hl,Spark2
 push af
 call CreateObject
 pop af
 ld (hl),-SPARKSPEED
 dec hl
 ld (hl),0
 add a,10
 cp RIGHTBOUND
 ret nc
 ld b,a
 ld c,-7
 ld de,BasicObjectUpdateFunction1
 ld hl,Spark2
 push af
 call CreateObject
 pop af
 ld (hl),SPARKSPEED
 dec hl
 ld (hl),0
 jr CSVertLoop2
 ret
;1 missile coming from one direction that follows you
;First spare byte: Default X modification (if vertical, will only change to follow you)
;Second spare byte: Default Y modification (if horizontal, will only change to follow you)
CreateHomingMissile:
 ld b,HMISSILEPOINTDELAY
 call AddPointStack
 call RandomNumber
 and 1
 jr z,SetHMissileVert
 ld hl,HomingMissileRight
 call RandomNumber
 ld d,HMISSILESPEED
 ld e,-7
 and 1
 jr z,$+10
 ld d,-HMISSILESPEED
 ld e,104
 ld bc,16
 add hl,bc
 call RandomNumber
 cp DOWNBOUND-2
 jr nc,$-5
 add a,2
 ld c,a
 ld b,e
 push de
 ld de,HMissileHorizUpdateFunction
 call CreateObject
 pop de
 ld (hl),0
 dec hl
 ld (hl),d
 ret
SetHMissileVert:
 ld hl,HomingMissileDown
 call RandomNumber
 ld d,HMISSILESPEED
 ld e,-7
 and 1
 jr z,$+10
 ld d,-HMISSILESPEED
 ld e,64
 ld bc,16
 add hl,bc
 call RandomNumber
 cp RIGHTBOUND-2
 jr nc,$-5
 add a,2
 ld b,a
 ld c,e
 push de
 ld de,HMissileVertUpdateFunction
 call CreateObject
 pop de
 ld (hl),d
 dec hl
 ld (hl),0
 ret
;A black hole that attracts you to it
;Spare bytes not used
CreateBlackHole:
 ld b,BLACKHOLEPOINTDELAY
 call AddPointStack
 call RandomNumber
 cp RIGHTBOUND-2
 jr nc,$-5
 add a,2
 ld d,a
 call RandomNumber
 cp DOWNBOUND-2
 jr nc,$-5
 ld b,d
 add a,2
 ld c,a
 ld de,BlackHoleUpdateFunction
 ld hl,BlackHole1
 jp CreateObject
;Repeller that pushes you away
;Spare bytes not used
CreateRepel:
 ld b,REPELPOINTDELAY
 call AddPointStack
 call RandomNumber
 cp RIGHTBOUND-2
 jr nc,$-5
 add a,2
 ld d,a
 call RandomNumber
 cp DOWNBOUND-2
 jr nc,$-5
 ld b,d
 add a,2
 ld c,a
 ld de,RepelUpdateFunction
 ld hl,Repel1
 jp CreateObject
;Ball that will bounce across the screen
;First spare byte: Height modification
;Second Spare Byte: X modification (+1 or -1)
CreateBounceball:
 ld b,BBALLPOINTDELAY
 call AddPointStack
 ld c,11
 ld de,BounceballUpdateFunction
 ld hl,Bounceball
 call CreateObject
 ld (hl),1
 call RandomNumber
 cp 128
 push af
 jr c,$+4
 ld (hl),-1
 dec hl
 ld (hl),BBALLMODNUM/2
 dec hl
 dec hl
 dec hl
 dec hl
 ld (hl),0
 pop af
 jr c,$+4
 ld (hl),RIGHTBOUND
 ret
;A ball that ricochets off the walls, like a Jezzball
;First spare byte: Time left on screen
;Second spare byte: X/Y modifiers (4 bits each)
CreateRicochet:
 ld b,RICOCHETPOINTDELAY
 call AddPointStack
 call RandomNumber
 and %01110111
 ld b,a
 and %00110000
 jr nz,$+4
 set 4,b
 ld a,b
 and %00000011
 jr nz,$+4
 set 0,b
 push bc
 call RandomNumber
 pop bc
 cp 64
 jr c,CRTop
 cp 128
 jr c,CRBottom
 cp 192
 jr c,CRLeft
CRRight:
 set 6,b
 push bc
 call RandomNumber
 cp DOWNBOUND
 jr nc,$-5
 ld c,a
 ld b,RIGHTBOUND
 jr CREnd
CRLeft:
 res 6,b
 push bc
 call RandomNumber
 cp DOWNBOUND
 jr nc,$-5
 ld c,a
 ld b,LEFTBOUND
 jr CREnd
CRBottom:
 set 2,b
 push bc
 call RandomNumber
 cp RIGHTBOUND
 jr nc,$-5
 ld b,a
 ld c,DOWNBOUND
 jr CREnd
CRTop:
 res 2,b
 push bc
 call RandomNumber
 cp RIGHTBOUND
 jr nc,$-5
 ld b,a
 ld c,UPBOUND
CREnd:
 ld hl,Ricochet
 ld de,RicochetUpdateFunction
 call CreateObject
 pop bc
 ld (hl),b
 dec hl
 ld (hl),RICOCHETTIME
 ret
;Orb that will throw stuff in random directions
;First spare byte: X modification (+1 or -1)
;Second spare byte: Time left until next throw
CreateOrbOfDeath:
 ld b,DEATHORBPOINTDELAY
 call AddPointStack
 call RandomNumber
 ld bc,$F91C
 ld d,ORBOFDEATHSPEED
 cp 128
 jr c,$+7
 ld bc,$681C
 ld d,-ORBOFDEATHSPEED
 push de
 ld hl,Orb
 ld de,OrbOfDeathUpdateFunction
 call CreateObject
 pop de
 ld (hl),ORBOFDEATHDELAY
 dec hl
 ld (hl),d
 ret
;Ghost from Pac-Man
;First spare byte: X-modification
;Second spare byte: Unused
CreateGhost:
 ld b,PACMANPOINTDELAY
 call AddPointStack
 call RandomNumber
 ld b,-8
 ld d,PACMANSPEED
 and 1
 jr z,$+6
 ld b,RIGHTEDGE
 ld d,-PACMANSPEED
 push bc
 call RandomNumber
 pop bc
 cp DOWNBOUND-2
 jr nc,$-7
 add a,2
 ld c,a
 push de
 ld de,GhostUpdateFunction
 ld hl,Ghost
 call CreateObject
 pop de
 dec hl
 ld (hl),d
 ret
;
;Object Update Functions
;
;DE -> Second byte of object (AIFunc Byte 2)
;
BombUpdateFunction:
 ld hl,5
 add hl,de
;HL -> First spare byte
 ld a,(hl)
 inc (hl)
 cp BOMBDELAY
 jr z,BombExplode
 ld de,Bomb1
 rra
 rra
 rra
 jr nc,$+5
 ld de,Bomb2
 dec hl
 ld (hl),d
 dec hl
 ld (hl),e
 ret
BombExplode:
 dec hl
 dec hl
 dec hl
 ld c,(hl)
 dec hl
 ld b,(hl)
 dec hl
 dec hl
 call DeleteObject
;
;Determine how the bomb should explode.
;Type 1: 8-Directional
;Type 2: Horizontal and vertical across the screen.
;
 push bc
 call RandomNumber
 pop bc
 cp 128
 jr c,CreateShrapnelType2
CreateShrapnelType1:
 ld ix,ShrapnelUpdateData
 ld a,8
CreateShrapnelType1Loop:
 push af
 push bc
 ld de,BasicObjectUpdateFunction1
 ld hl,ShrapnelType1
 call CreateObject
 dec hl
 ld a,(ix)
 ld (hl),a
 inc hl
 inc ix
 ld a,(ix)
 ld (hl),a
 inc ix
 pop bc
 pop af
 dec a
 jr nz,CreateShrapnelType1Loop
 ret
CreateShrapnelType2:
 push bc
 push bc
 push bc
 ld a,b
 sub 8
 ld b,a
CreateShrapnelType2Loop1:
 ld de,ShrapnelType2Function
 ld hl,ShrapnelType2Horiz1
 call CreateObject
 ld (hl),SHRAPNELTYPE2TIMER
 ld a,b
 sub 8
 ld b,a
 add a,8
 cp 128
 jr c,CreateShrapnelType2Loop1
 pop bc
 ld a,b
 add a,8
 ld b,a
CreateShrapnelType2Loop2:
 ld de,ShrapnelType2Function
 ld hl,ShrapnelType2Horiz1
 call CreateObject
 ld (hl),SHRAPNELTYPE2TIMER
 ld a,b
 add a,8
 ld b,a
 cp RIGHTEDGE
 jr c,CreateShrapnelType2Loop2
 pop bc
 ld a,c
 sub 8
 ld c,a
CreateShrapnelType2Loop3:
 ld de,ShrapnelType2Function
 ld hl,ShrapnelType2Vert1
 call CreateObject
 ld (hl),SHRAPNELTYPE2TIMER
 ld a,c
 sub 8
 ld c,a
 add a,8
 cp 128
 jr c,CreateShrapnelType2Loop3
 pop bc
 ld a,c
 add a,8
 ld c,a
CreateShrapnelType2Loop4:
 ld de,ShrapnelType2Function
 ld hl,ShrapnelType2Vert1
 call CreateObject
 ld (hl),SHRAPNELTYPE2TIMER
 ld a,c
 add a,8
 ld c,a
 cp 64
 jr c,CreateShrapnelType2Loop4
 ret
;
ShrapnelType2Function:
 ld hl,6
 add hl,de
 ld a,(hl)
 dec (hl)
 or a
 jr nz,Shrapnel2StillGoing
;Timer run-out
 ld de,7
 sbc hl,de
 jp DeleteObject
Shrapnel2StillGoing
;HL -> Spare 2
 dec hl
 dec hl
 ld b,(hl)
 dec hl
 ld c,(hl)
;HL -> Sprite Address
;BC = Sprite Address
 cp SHRAPNELTYPE2TIMER*2/3
 jr z,Shrapnel2AdvanceSprite
 cp SHRAPNELTYPE2TIMER/3
 ret nz
Shrapnel2AdvanceSprite:
 ex de,hl
 ld hl,16
 add hl,bc
 ex de,hl
 ld (hl),e
 inc hl
 ld (hl),d
 ret
;
HMissileHorizUpdateFunction:
 ex de,hl
 inc hl
 inc hl
;HL -> Y Coord
 ld b,(hl)
 ld a,(ManY)
 cp b
 jr z,EndHMissileUpdate+1
 jr c,$+5
;ManY > HMissileY
 inc (hl)
 jr EndHMissileUpdate+1
;ManY < HMissileY
 dec (hl)
 jr EndHMissileUpdate+1
HMissileVertUpdateFunction:
 ex de,hl
 inc hl
;HL -> X Coord
 ld b,(hl)
 ld a,(ManX)
 cp b
 jr z,EndHMissileUpdate
 jr c,$+5
;ManX > HMissileY
 inc (hl)
 jr EndHMissileUpdate
;ManX < HMissileY
 dec (hl)
; jr EndHMissileUpdate
EndHMissileUpdate:
 inc hl
 inc hl
 inc hl
 inc hl
;HL -> First spare byte
 jp BasicObjectUpdateFunction1+4
;
BlackHoleUpdateFunction:
 ld hl,5
 add hl,de
;HL -> First spare byte
 ld a,(hl)
 inc (hl)
 cp BLACKHOLEDELAY
 jr z,DestroyBlackHole
 ld de,BlackHole1
 rra
 push af
 rra
 rra
 jr nc,$+5
 ld de,BlackHole2
 dec hl
 ld (hl),d
 dec hl
 ld (hl),e
 pop af
 ret c
 dec hl
;HL->Y Coord
 ld de,ManY
 ex de,hl
;HL->ManY
;DE->Y Coord
 ld b,(hl)
 ld a,(de)
 cp b
 jr z,BHCheckXCoord
 ld a,(hl)
 jr c,$+5
;ManY > Y Coord
 inc (hl)
 jr BHCheckXCoord
;ManY < Y Coord
 dec (hl)
BHCheckXCoord:
 dec hl
 dec de
;HL->ManX
;DE->X Coord
 ld b,(hl)
 ld a,(de)
 cp b
 ret z
 ld a,(hl)
 jr c,$+4
;ManX > X Coord
 inc (hl)
 ret
;ManX < X Coord
 dec (hl)
 ret
DestroyBlackHole:
 ld de,-6
 add hl,de
 jp DeleteObject
;
RepelUpdateFunction:
 ld hl,5
 add hl,de
;HL -> First spare byte
 ld a,(hl)
 inc (hl)
 cp REPELDELAY
 jr z,DestroyRepel
 ld de,Repel1
 rra
 push af
 rra
 rra
 jr nc,$+5
 ld de,Repel2
 dec hl
 ld (hl),d
 dec hl
 ld (hl),e
 pop af
 ret c
 dec hl
;HL->Y Coord
 ld de,ManY
 ex de,hl
;HL->ManY
;DE->Y Coord
 ld b,(hl)
 ld a,(de)
 cp b
 jr z,RCheckXCoord
 ld a,(hl)
 jr c,$+9
;ManY > Y Coord
 cp UPBOUND+1
 jr c,RCheckXCoord
 dec (hl)
 jr RCheckXCoord
;ManY < Y Coord
 cp DOWNBOUND-1
 jr nc,RCheckXCoord
 inc (hl)
RCheckXCoord:
 dec hl
 dec de
;HL->ManX
;DE->X Coord
 ld b,(hl)
 ld a,(de)
 cp b
 ret z
 ld a,(hl)
 jr c,$+7
;ManX > X Coord
 cp LEFTBOUND+1
 ret c
 dec (hl)
 ret
;ManX < X Coord
 cp RIGHTBOUND-1
 ret nc
 inc (hl)
 ret
DestroyRepel:
 ld de,-6
 add hl,de
 jp DeleteObject
;
BounceballUpdateFunction:
 ld hl,6
 add hl,de
;HL->Second spare byte (X-Adjustment)
 inc de
;DE->X Coord
 ld a,(de)
 add a,(hl)
 ld (de),a
 add a,8
 cp RIGHTBOUND+16
 jr nc,DestroyBounceball
 dec hl
 inc (hl)
 ld b,(hl)
 ld a,(hl)
 cp BBALLMODNUM + 1
 jr nz,$+4
 ld (hl),0
 ld a,BBALLMODNUM/2 + 1
 sub b
 push af
 jr nc,$+4
 cpl
 inc a
 sra a
 sra a
 ld b,a
 pop af
 jr c,$+6
 ld a,b
 cpl
 inc a
 ld b,a
 inc de
 ld a,(de)
 add a,b
 ld (de),a
 ret
DestroyBounceball:
 dec de
 dec de
 ex de,hl
 jp DeleteObject
;
RicochetUpdateFunction:
 ld hl,5
 add hl,de
;HL->First spare byte (timer)
 dec (hl)
 jr z,DestroyRicochet
 inc hl
;HL->Second spare byte (X/Y modifiers)
 ld c,(hl)
 ex de,hl
 inc hl
;HL->X coord
 ld a,c
 and %00110000
 rra
 rra
 rra
 rra
 bit 6,c
 jr z,$+4
 cpl
 inc a
 ld b,a
 add a,(hl)
 ld (hl),a
 add a,b
 cp RIGHTBOUND+4
 jr c,$+6
 ld a,c
 xor %01000000
 ld c,a
 inc hl
 ld a,c
 and %00000011
 bit 2,c
 jr z,$+4
 cpl
 inc a
 ld b,a
 add a,(hl)
 ld (hl),a
 add a,b
 cp DOWNBOUND+4
 jr c,$+6
 ld a,c
 xor %00000100
 ld c,a
 ld de,4
 add hl,de
 ld (hl),c
 ret
DestroyRicochet:
 ex de,hl
 dec hl
 jp DeleteObject
;
OrbOfDeathUpdateFunction:
 ld hl,5
 add hl,de
;HL->First spare byte (X-Mod)
 inc de
 ld a,(de)
 ld b,a
 add a,(hl)
 ld (de),a
 add a,8
 cp RIGHTEDGE+16
 jr nc,DestroyOrbOfDeath
 inc de
 ld a,(de)
 ld c,a
 inc hl
;HL->Timer
 dec (hl)
 ret nz
;Time to create new object
 ld (hl),ORBOFDEATHDELAY
 push bc
 call RandomNumber
 ld d,a
 rra
 and %00000011
 inc a
 bit 7,d
 jr z,$+4
 cpl
 inc a
 ld d,a
 call RandomNumber
 ld e,a
 rra
 and %00000011
 inc a
 bit 7,e
 jr z,$+4
 cpl
 inc a
 ld e,a
 pop bc
 push de
 ld de,BasicObjectUpdateFunction1
 ld hl,Ricochet
 call CreateObject
 pop de
 ld (hl),d
 dec hl
 ld (hl),e
 ret
DestroyOrbOfDeath:
 dec de
 dec de
 ex de,hl
 jp DeleteObject
;
GhostUpdateFunction:
 ld hl,5
 add hl,de
 inc de
 ld a,(de)
 or a
 jr z,CreatePacMan
 cp RIGHTEDGE-8
 jr z,CreatePacMan
 add a,(hl)
 ld (de),a
 ret
CreatePacMan:
 push hl
 push de
 push hl
 dec de
 dec de
 ld hl,BasicObjectUpdateFunction1
 ex de,hl
 ld (hl),d
 inc hl
 ld (hl),e
 pop hl
 pop de
 ld a,(de)
 add a,10
 ld b,a
 ld a,(hl)
 ld hl,PacManL1
 cp 2
 jr nz,$+9
 ld a,-20
 add a,b
 ld b,a
 ld hl,PacManR1
 inc de
 ld a,(de)
 ld c,a
 ld de,PacManUpdateFunction
 call CreateObject
 ld (hl),PACMANANIMDELAY
 dec hl
 pop de
 ld a,(de)
 ld (hl),a
 ret
;
PacManUpdateFunction:
 ld hl,5
 add hl,de
 inc de
 ld a,(de)
 add a,(hl)
 ld (de),a
 add a,10
 cp RIGHTEDGE+11
 jr nc,DestroyPacMan
 inc de
 inc de
 inc hl
 dec (hl)
 ret nz
 ld (hl),PACMANANIMDELAY
 dec hl
 ld a,(hl)
 cp 2
 jr z,PacManRightUpdate
 ld hl,PacManL1
 ld a,(de)
 cp l
 jr nz,$+5
 ld hl,PacManL2
 ex de,hl
 ld (hl),e
 inc hl
 ld (hl),d
 ret
PacManRightUpdate:
 ld hl,PacManR1
 ld a,(de)
 cp l
 jr nz,$+5
 ld hl,PacManR2
 ex de,hl
 ld (hl),e
 inc hl
 ld (hl),d
 ret
DestroyPacMan:
 dec de
 dec de
 ex de,hl
 jp DeleteObject
;
;Uses last two bytes (the spare bytes) of an object as x/y coordinate modifiers.
; Updates the object by adding current x/y with the spare bytes numbers.
; Objects are destroyed when off the screen.
;
BasicObjectUpdateFunction1:
 ld hl,5
 add hl,de
 ld b,(hl)
 inc hl
 ld c,(hl)
 dec hl
 dec hl
 dec hl
 dec hl
 ld a,(hl)
 add a,c
 ld (hl),a
 dec hl
 add a,9
 cp 73
 jr nc,BasicObjectDestroy
 ld a,(hl)
 add a,b
 ld (hl),a
 add a,9
 cp 113
 ret c
BasicObjectDestroy:
 dec hl
 dec hl
 jp DeleteObject
;
;Object Sprites
;
Bomb1:
 .db %00011000
 .db %00000100
 .db %00011100
 .db %00111110
 .db %00111110
 .db %00111110
 .db %00111110
 .db %00011100
 .db %00011000
 .db %00000100
 .db %00011100
 .db %00111110
 .db %00111110
 .db %00111110
 .db %00111110
 .db %00011100
;
Bomb2:
 .db %00011000
 .db %00000100
 .db %00111100
 .db %01111110
 .db %01111110
 .db %01111110
 .db %01111110
 .db %00111100
 .db %00011000
 .db %00000100
 .db %00111100
 .db %01111110
 .db %01111110
 .db %01111110
 .db %01111110
 .db %00111100
;
ShrapnelType1:
 .db %00011000
 .db %00111110
 .db %01111111
 .db %01111110
 .db %11111111
 .db %00111111
 .db %00111100
 .db %00001000
 .db %00011000
 .db %00111110
 .db %01111111
 .db %01111110
 .db %11111111
 .db %00111111
 .db %00111100
 .db %00001000
;
ShrapnelType2Horiz1:
 .db %00000000
 .db %00000000
 .db %01100110
 .db %11111111
 .db %11111111
 .db %01100110
 .db %00000000
 .db %00000000
 .db %00000000
 .db %00000000
 .db %01100110
 .db %11111111
 .db %11111111
 .db %01100110
 .db %00000000
 .db %00000000
;
ShrapnelType2Horiz2:
 .db %01100110
 .db %11111111
 .db %11111111
 .db %10001000
 .db %00010001
 .db %11111111
 .db %11111111
 .db %01100110
 .db %01100110
 .db %11111111
 .db %11111111
 .db %10001000
 .db %00010001
 .db %11111111
 .db %11111111
 .db %01100110
;
ShrapnelType2Horiz3:
 .db %01100110
 .db %10011001
 .db %00000000
 .db %00000000
 .db %00000000
 .db %00000000
 .db %10011001
 .db %01100110
 .db %01100110
 .db %10011001
 .db %00000000
 .db %00000000
 .db %00000000
 .db %00000000
 .db %10011001
 .db %01100110
;
ShrapnelType2Vert1:
 .db %00011000
 .db %00111100
 .db %00111100
 .db %00011000
 .db %00011000
 .db %00111100
 .db %00111100
 .db %00011000
 .db %00011000
 .db %00111100
 .db %00111100
 .db %00011000
 .db %00011000
 .db %00111100
 .db %00111100
 .db %00011000
;
ShrapnelType2Vert2:
 .db %01101110
 .db %11100111
 .db %11100111
 .db %01110110
 .db %01101110
 .db %11100111
 .db %11100111
 .db %01110110
 .db %01101110
 .db %11100111
 .db %11100111
 .db %01110110
 .db %01101110
 .db %11100111
 .db %11100111
 .db %01110110
;
ShrapnelType2Vert3:
 .db %01000010
 .db %10000001
 .db %10000001
 .db %01000010
 .db %01000010
 .db %10000001
 .db %10000001
 .db %01000010
 .db %01000010
 .db %10000001
 .db %10000001
 .db %01000010
 .db %01000010
 .db %10000001
 .db %10000001
 .db %01000010
;
Spark1:
 .db %00000000
 .db %00000001
 .db %00010010
 .db %00110110
 .db %01111100
 .db %01011000
 .db %10010000
 .db %00000000
 .db %00000000
 .db %00000001
 .db %00010010
 .db %00110110
 .db %01111100
 .db %01011000
 .db %10010000
 .db %00000000
;
Spark2:
 .db %01000000
 .db %00110000
 .db %00011000
 .db %00001100
 .db %00111110
 .db %00011000
 .db %00001100
 .db %00000010
 .db %01000000
 .db %00110000
 .db %00011000
 .db %00001100
 .db %00111110
 .db %00011000
 .db %00001100
 .db %00000010
;
HomingMissileDown:
 .db %00000000
 .db %00000000
 .db %00010100
 .db %00001000
 .db %00010100
 .db %00010100
 .db %00001000
 .db %00000000
 .db %00000000
 .db %00000000
 .db %00010100
 .db %00001000
 .db %00011100
 .db %00011100
 .db %00001000
 .db %00000000
;
HomingMissileUp:
 .db %00000000
 .db %00010000
 .db %00101000
 .db %00101000
 .db %00010000
 .db %00101000
 .db %00000000
 .db %00000000
 .db %00000000
 .db %00010000
 .db %00111000
 .db %00111000
 .db %00010000
 .db %00101000
 .db %00000000
 .db %00000000
;
HomingMissileRight:
 .db %00000000
 .db %00000000
 .db %00101100
 .db %00010010
 .db %00101100
 .db %00000000
 .db %00000000
 .db %00000000
 .db %00000000
 .db %00000000
 .db %00101100
 .db %00011110
 .db %00101100
 .db %00000000
 .db %00000000
 .db %00000000
;
HomingMissileLeft:
 .db %00000000
 .db %00000000
 .db %00000000
 .db %00110100
 .db %01001000
 .db %00110100
 .db %00000000
 .db %00000000
 .db %00000000
 .db %00000000
 .db %00000000
 .db %00110100
 .db %01111000
 .db %00110100
 .db %00000000
 .db %00000000
;
BlackHole1:
 .db %00111100
 .db %01000010
 .db %10011001
 .db %10111101
 .db %10111101
 .db %10011001
 .db %01000010
 .db %00111100
 .db %00111100
 .db %01111110
 .db %11111111
 .db %11111111
 .db %11111111
 .db %11111111
 .db %01111110
 .db %00111100
;
BlackHole2:
 .db %00000000
 .db %00111100
 .db %01111110
 .db %01111110
 .db %01111110
 .db %01111110
 .db %00111100
 .db %00000000
 .db %00000000
 .db %00111100
 .db %01111110
 .db %01111110
 .db %01111110
 .db %01111110
 .db %00111100
 .db %00000000
;
Repel1:
 .db %00000000
 .db %00111100
 .db %01000010
 .db %01011010
 .db %01011010
 .db %01000010
 .db %00111100
 .db %00000000
 .db %00000000
 .db %00111100
 .db %01111110
 .db %01111110
 .db %01111110
 .db %01111110
 .db %00111100
 .db %00000000
;
Repel2:
 .db %00111100
 .db %01000010
 .db %10011001
 .db %10100101
 .db %10100101
 .db %10011001
 .db %01000010
 .db %00111100
 .db %00111100
 .db %01111110
 .db %11111111
 .db %11111111
 .db %11111111
 .db %11111111
 .db %01111110
 .db %00111100
;
Bounceball:
 .db %00000000
 .db %00111100
 .db %01000010
 .db %01000010
 .db %01000010
 .db %01000010
 .db %00111100
 .db %00000000
 .db %00000000
 .db %00111100
 .db %01111110
 .db %01111110
 .db %01111110
 .db %01111110
 .db %00111100
 .db %00000000
;
Ricochet:
 .db %00000000
 .db %00000000
 .db %00011000
 .db %00111100
 .db %00111100
 .db %00011000
 .db %00000000
 .db %00000000
 .db %00000000
 .db %00000000
 .db %00011000
 .db %00111100
 .db %00111100
 .db %00011000
 .db %00000000
 .db %00000000
;
Orb:
 .db %00000000
 .db %00111100
 .db %01111110
 .db %01111110
 .db %01111110
 .db %01111110
 .db %00111100
 .db %00000000
 .db %00000000
 .db %00111100
 .db %01111110
 .db %01111110
 .db %01111110
 .db %01111110
 .db %00111100
 .db %00000000
;
Ghost:
 .db %00000000
 .db %00111100
 .db %01111110
 .db %01011010
 .db %01111110
 .db %01000010
 .db %01111110
 .db %01011010
 .db %00000000
 .db %00111100
 .db %01111110
 .db %01111110
 .db %01111110
 .db %01111110
 .db %01111110
 .db %01011010
;
PacManL1:
 .db %00000000
 .db %00111100
 .db %01101110
 .db %00111110
 .db %00011110
 .db %01111110
 .db %00111100
 .db %00000000
 .db %00000000
 .db %00111100
 .db %01111110
 .db %00111110
 .db %00011110
 .db %01111110
 .db %00111100
 .db %00000000
;
PacManL2:
 .db %00000000
 .db %00111100
 .db %01101110
 .db %01111110
 .db %01111110
 .db %01111110
 .db %00111100
 .db %00000000
 .db %00000000
 .db %00111100
 .db %01111110
 .db %01111110
 .db %01111110
 .db %01111110
 .db %00111100
 .db %00000000
;
PacManR1:
 .db %00000000
 .db %00111100
 .db %01110110
 .db %01111100
 .db %01111000
 .db %01111110
 .db %00111100
 .db %00000000
 .db %00000000
 .db %00111100
 .db %01111110
 .db %01111100
 .db %01111000
 .db %01111110
 .db %00111100
 .db %00000000
;
PacManR2:
 .db %00000000
 .db %00111100
 .db %01110110
 .db %01111110
 .db %01111110
 .db %01111110
 .db %00111100
 .db %00000000
 .db %00000000
 .db %00111100
 .db %01111110
 .db %01111110
 .db %01111110
 .db %01111110
 .db %00111100
 .db %00000000
;
