;---------------------------------------
;
; Dodger include file
;
; Contains all data and code used for
;  power-ups in Dodger
;
; The main engine code does not need to
;  be changed when new power-ups are added.
;  However, you must update 2 constants
;  in the main file, and (possibly) add
;  labels if you want to modify something
;  in the engine (see invincibility and
;  control-swap power-ups).
;
;---------------------------------------
;
;Power-up functions
;
;For Activate functions:
; DE -> Time
;
;For Deactivate functions:
; DE -> Active
;
PULifeUpActivate:
 ex de,hl
 ld (hl),1
 ld a,(Life)
 add a,10
 cp 100
 jr c,$+4
 ld a,99
 ld (Life),a
 ret
PULifeUpDeactivate:
 ex de,hl
 dec hl
 ld (hl),0
 ret
PULifeDownActivate:
 ex de,hl
 ld (hl),1
 ld a,(Life)
 sub 10
 jr nc,$+3
 xor a
 ld (Life),a
 ret
PULifeDownDeactivate:
 ex de,hl
 dec hl
 ld (hl),0
 ret
PUInvincibilityActivate:
 ex de,hl
 ld (hl),INVINCIBILITYTIME
 ld hl,DmgMod1
 ld (hl),NOPCODE
 ld hl,DmgMod2
 ld (hl),NOPCODE
 ret
PUInvincibilityDeactivate:
 ex de,hl
 dec hl
 ld (hl),0
 ld hl,DmgMod1
 ld (hl),DECHLCODE
 ld hl,DmgMod2
 ld (hl),DECHLCODE
 ret
PUSpeedUpActivate:
 ex de,hl
 ld (hl),SPEEDUPTIME
 ld hl,ManSpeed
 inc (hl)
 ret
PUSpeedUpDeactivate:
 ex de,hl
 dec hl
 ld (hl),0
 ld hl,ManSpeed
 dec (hl)
 ret
PUSpeedDownActivate:
 ex de,hl
 ld (hl),SPEEDDOWNTIME
 ld hl,ManSpeed
 dec (hl)
 ret nc
 inc (hl)
 ret
PUSpeedDownDeactivate:
 ex de,hl
 dec hl
 ld (hl),0
 ld hl,ManSpeed
 inc (hl)
 ret
PUControlActivate:
 ex de,hl
 ld (hl),CONTROLTIME
 ld hl,KeyModUp
 ld de,KeyModDown
 call PUControlSwap
 ld hl,KeyModLeft
 ld de,KeyModRight
 jr PUControlSwap
PUControlDeactivate:
 ex de,hl
 dec hl
 ld (hl),0
 ld hl,KeyModUp
 ld de,KeyModDown
 call PUControlSwap
 ld hl,KeyModLeft
 ld de,KeyModRight
PUControlSwap:
 ld b,(hl)
 ld a,(de)
 ld (hl),a
 ld a,b
 ld (de),a
 inc hl
 inc de
 ld b,(hl)
 ld a,(de)
 ld (hl),a
 ld a,b
 ld (de),a
 ret
PUClearActivate:
 ex de,hl
 ld (hl),1
 ld hl,NumObjects
 ld a,(hl)
 or a
 ret z
 ld b,a
 ld (hl),0
 ld hl,OBJECTADDR-8
 ld de,8
PUClearLoop:
 add hl,de
 ld a,(hl)
 or a
 jr z,PUClearLoop
 ld (hl),0
 djnz PUClearLoop
 ld hl,POINTSTACK-1
 ld a,(NumPointStack)
 ld b,a
PSSetLoop:
 inc hl
 ld a,(hl)
 or a
 jr z,PSSetLoop
 ld (hl),1
 djnz PSSetLoop
 ret
PUClearDeactivate:
 ex de,hl
 dec hl
 ld (hl),0
 ret
PUArrowUpActivate:
 ex de,hl
 ld (hl),1
 ld hl,ManY
 ld a,(hl)
 sub ARROWCHANGE+UPBOUND
 cp 200
 jr c,$+3
 xor a
 add a,UPBOUND
 ld (hl),a
 ret
PUArrowUpDeactivate:
 ex de,hl
 dec hl
 ld (hl),0
 ret
PUArrowDownActivate:
 ex de,hl
 ld (hl),1
 ld hl,ManY
 ld a,(hl)
 add a,ARROWCHANGE
 cp DOWNBOUND
 jr c,$+4
 ld a,DOWNBOUND-1
 ld (hl),a
 ret
PUArrowDownDeactivate:
 ex de,hl
 dec hl
 ld (hl),0
 ret
PUArrowLeftActivate:
 ex de,hl
 ld (hl),1
 ld hl,ManX
 ld a,(hl)
 sub ARROWCHANGE+LEFTBOUND
 cp 200
 jr c,$+3
 xor a
 add a,LEFTBOUND
 ld (hl),a
 ret
PUArrowLeftDeactivate:
 ex de,hl
 dec hl
 ld (hl),0
 ret
PUArrowRightActivate:
 ex de,hl
 ld (hl),1
 ld hl,ManX
 ld a,(hl)
 add a,ARROWCHANGE
 cp RIGHTBOUND
 jr c,$+4
 ld a,RIGHTBOUND-1
 ld (hl),a
 ret
PUArrowRightDeactivate:
 ex de,hl
 dec hl
 ld (hl),0
 ret
PUObjectSpawnDownActivate:
 ex de,hl
 ld (hl),OBJECTSPEEDDOWNTIME
 jr DecObjectSpeed
PUObjectSpawnDownDeactivate:
 ex de,hl
 dec hl
 ld (hl),0
 jr IncObjectSpeed
PUObjectSpawnUpActivate:
 ex de,hl
 ld (hl),OBJECTSPEEDUPTIME
 jr IncObjectSpeed
PUObjectSpawnUpDeactivate:
 ex de,hl
 dec hl
 ld (hl),0
DecObjectSpeed:
 ld hl,StartDelay
 ld a,(hl)
 sub OBJECTSPEEDCHANGE
 cp MINDELAY
 ret c
 ld (hl),a
 ret
IncObjectSpeed:
 ld hl,StartDelay
 ld a,(hl)
 add a,OBJECTSPEEDCHANGE
 ld (hl),a
 ret
PUStickyTileActivate:
 ld hl,-5
 add hl,de
 ld de,ManSpeed
 ld a,(de)
 or %10000000
 ld (hl),a
 xor a
 ld (de),a
 ld de,5
 add hl,de
 ld (hl),STICKYTILETIME
 ret
PUStickyTileDeactivate:
 ex de,hl
 dec hl
 ld a,(hl)
 and %01111111
 ld de,ManSpeed
 ld (de),a
 ld (hl),0
 ret
PUTimeStopActivate:
 ex de,hl
 ld (hl),TIMESTOPTIME
 ld hl,TimeStopMod1
 ld (hl),JPCODE
 ld hl,TimeStopMod2
 ld (hl),NOPCODE
 ld hl,TimeStopMod3
 ld (hl),RETCODE
 ret
PUTimeStopDeactivate:
 ex de,hl
 dec hl
 ld (hl),0
 ld hl,TimeStopMod1
 ld (hl),JPZCODE
 ld hl,TimeStopMod2
 ld (hl),DECHLCODE
 ld hl,TimeStopMod3
 ld (hl),NOPCODE
 ret
;
;Power-Up Sprites
;
PUSprites:
;
LifeUpPU:
 .db %11111111
 .db %10011001
 .db %10011001
 .db %11111111
 .db %11111111
 .db %10011001
 .db %10011001
 .db %11111111
 .db %11111111
 .db %10011001
 .db %10011001
 .db %11111111
 .db %11111111
 .db %10011001
 .db %10011001
 .db %11111111
;
LifeDownPU:
 .db %00111100
 .db %01111110
 .db %11100111
 .db %11000011
 .db %11100111
 .db %11100111
 .db %11100111
 .db %11111111
 .db %00111100
 .db %01111110
 .db %11111111
 .db %11111111
 .db %11111111
 .db %11111111
 .db %11111111
 .db %11111111
;
InvincibilityPU:
 .db %01000000
 .db %10100000
 .db %10101111
 .db %01001111
 .db %11101111
 .db %01001111
 .db %10100110
 .db %10100000
 .db %01000000
 .db %10100000
 .db %10101111
 .db %01001111
 .db %11101111
 .db %01001111
 .db %10100110
 .db %10100000
;
SpeedUpPU:
 .db %00000110
 .db %11101001
 .db %00000110
 .db %11101110
 .db %00000110
 .db %11011110
 .db %00010010
 .db %11000011
 .db %00000110
 .db %11101111
 .db %00000110
 .db %11101110
 .db %00000110
 .db %11011110
 .db %00010010
 .db %11000011
;
SpeedDownPU:
 .db %00110000
 .db %01001000
 .db %00110000
 .db %01110000
 .db %00110111
 .db %11110000
 .db %10010000
 .db %00011000
 .db %00110000
 .db %01111000
 .db %00110000
 .db %01110000
 .db %00110111
 .db %11110000
 .db %10010000
 .db %00011000
;
ControlSwapPU:
 .db %00000100
 .db %00000110
 .db %11111111
 .db %00100110
 .db %01100100
 .db %11111111
 .db %01100000
 .db %00100000
 .db %00000100
 .db %00000110
 .db %11111111
 .db %00100110
 .db %01100100
 .db %11111111
 .db %01100000
 .db %00100000
;
ClearPU:
 .db %11111111
 .db %10000001
 .db %10000001
 .db %10000001
 .db %10000001
 .db %10000001
 .db %10000001
 .db %11111111
 .db %11111111
 .db %11111111
 .db %11111111
 .db %11111111
 .db %11111111
 .db %11111111
 .db %11111111
 .db %11111111
;
ArrowUpPU:
 .db %11111111
 .db %11100111
 .db %11000011
 .db %10000001
 .db %11100111
 .db %11100111
 .db %11100111
 .db %11111111
 .db %11111111
 .db %11111111
 .db %11111111
 .db %11111111
 .db %11111111
 .db %11111111
 .db %11111111
 .db %11111111
;
ArrowDownPU:
 .db %11111111
 .db %11100111
 .db %11100111
 .db %11100111
 .db %10000001
 .db %11000011
 .db %11100111
 .db %11111111
 .db %11111111
 .db %11111111
 .db %11111111
 .db %11111111
 .db %11111111
 .db %11111111
 .db %11111111
 .db %11111111
;
ArrowLeftPU:
 .db %11111111
 .db %11101111
 .db %11001111
 .db %10000001
 .db %10000001
 .db %11001111
 .db %11101111
 .db %11111111
 .db %11111111
 .db %11111111
 .db %11111111
 .db %11111111
 .db %11111111
 .db %11111111
 .db %11111111
 .db %11111111
;
ArrowRightPU:
 .db %11111111
 .db %11110111
 .db %11110011
 .db %10000001
 .db %10000001
 .db %11110011
 .db %11110111
 .db %11111111
 .db %11111111
 .db %11111111
 .db %11111111
 .db %11111111
 .db %11111111
 .db %11111111
 .db %11111111
 .db %11111111
;
ObjectSpawnDownPU:
 .db %00000000
 .db %00100111
 .db %00010000
 .db %00110000
 .db %01111000
 .db %01111000
 .db %01111000
 .db %00110000
 .db %00000000
 .db %00100111
 .db %00010000
 .db %00110000
 .db %01111000
 .db %01111000
 .db %01111000
 .db %00110000
;
ObjectSpawnUpPU:
 .db %00000010
 .db %00100111
 .db %00010010
 .db %00110000
 .db %01111000
 .db %01111000
 .db %01111000
 .db %00110000
 .db %00000010
 .db %00100111
 .db %00010010
 .db %00110000
 .db %01111000
 .db %01111000
 .db %01111000
 .db %00110000
;
StickyTilePU:
 .db %10011001
 .db %10100101
 .db %10011001
 .db %10111101
 .db %11011011
 .db %10011001
 .db %10100101
 .db %10100101
 .db %10011001
 .db %10111101
 .db %10011001
 .db %10111101
 .db %11011011
 .db %10011001
 .db %10100101
 .db %10100101
;
TimeStopPU:
 .db %01111110
 .db %01000010
 .db %00100100
 .db %00011000
 .db %00011000
 .db %00100100
 .db %01000010
 .db %01111110
 .db %01111110
 .db %01111110
 .db %00111100
 .db %00011000
 .db %00011000
 .db %00111100
 .db %01111110
 .db %01111110
;
