;---------------------------------------
;
; Dodger include file
;
; Contains user-interrupt that is used
;  in Dodger
;
; Interrupt installs to the user-interrupt
;  location that is called by the default
;  TI-OS interrupt (im 1). This interrupt
;  corrects the down-left bug and also
;  is used to aid in FPS tracking (FPS
;  tracking can be turned off/on at compile
;  time).
;
;---------------------------------------

InstallInt:
 res 2,(iy+$23)                       ;turn user int off so it won't get called by
                                      ;accident before we're ready
   
 ld hl,int_copy                       ;copy prog to user int buffer
 ld de,_user_int_ram+1                            ;1 byte ahead of checksum
 ld bc,int_end-int_start              ;length of interrupt handler
 ldir                                 ;hl is the source, de is the destination,
                                      ;and bc is the length
   
 ld a,(_user_int_ram+1)               ;set up checksum byte
 ld hl,_user_int_ram+($28*1)          ;load byte
 add a,(hl)                           ;add to total
 ld hl,_user_int_ram+($28*2)          ;load byte
 add a,(hl)                           ;add to total
 ld hl,_user_int_ram+($28*3)          ;load byte
 add a,(hl)                           ;add to total
 ld hl,_user_int_ram+($28*4)          ;load byte
 add a,(hl)                           ;add to total
 ld hl,_user_int_ram+($28*5)          ;load byte
 add a,(hl)                           ;add to total
 ld (_user_int_ram),a                 ;load checksum in its location

 set 2,(iy+$23)                       ;turn it on
 ret

UninstallInt:
 res 2,(iy+$23)                       ;turn user int off
 ret

int_copy:
 .org $D2FE
int_start:
 in a,(3)
 bit 3,a
 jr z,no_down_left_bug
 and %11111110
 out (3),a
no_down_left_bug:
#ifdef DEBUG_FPS
 ld hl,InterruptCounter
 inc (hl)
 ld a,(hl)
 cp 200
 ret nz
 ld (hl),0
 inc hl
 inc hl
 ld (hl),1
#endif
 ret
int_end:
