;********************************************************
; -decompresses data that is vertically compressed with
; bmp2asm, by Levi Lansing    (total size=63 bytes)
; -(decompresses data into the video memory - 1024 bytes)
; -de=location of data to decompress
; -destroys- a,b,c,hl,de (points to byte after data)
;********************************************************
decompV:
 ld hl,$FC00        ;point hl to the screen mem
decompLoop:
 ld a,(de)          ;load the first byte of the compressed data
 cp $B7             ;check if it's a marker
 jr nz,DCnorm       ;if it's not, treat it as a normal byte
 inc de             ;if the byte is marked, the next byte tells us the value
 ld a,(de)          ;that is repeated so we
 ld c,a             ;put that in c
 inc de             ;the next byte tells us how many times it's repeated
 ld a,(de)
 ld b,a             ;we will load that into b to be used as a counter
 inc de             ;point to the next byte for later
DCrepeatLoop:
 ld (hl),c          ;put the value in the screen mem once
 push de            ;hide de
 ld de,16
 add hl,de          ;point hl to the next row (16 bytes forward)
 jr nc,DCloop       ;if hl isn't past the end of the screen data ($FFFF), then continue
 ld de,1022         ;if it is, we need to put it back to the next column
 sbc hl,de          ;point hl to the 1st row of the next column
 ld a, l
 cp $10             ;if l is over $10 (16d), it has completed the full screen
 jr c,DCloop        ;jump if it's no over $10 to continue
 pop de             ;restore de again
 ret                ;return from the routine
DCloop:
 pop de             ;restore de
 djnz DCrepeatLoop  ;decrement b and continue loading the same byte down the
                    ;column until b is 0
 jr decompLoop      ;continue with the next byte
DCnorm:
 ld (hl),a          ;load the byte into the screen mem
 inc de             ;point de to the next byte
 push de            ;hide it
 ld de, 16
 add hl,de          ;point hl to the next row (16 bytes forward)
 pop de             ;restore de
 jr nc,decompLoop   ;if hl did not go past $FFFF (it would flip to 0+) then continue
 push de            ;hide de again
 ld de, 1022
 sbc hl,de          ;subtracting 1022 from hl put's it at the 1st row of the next column
 ld a, l
 cp $10             ;check if hl is past the first row (if it is, we finished decompressing)
 pop de             ;restore de again
 jr c,decompLoop    ;if we're not done, keep going...
 ret                ;if we get here, we're done and will return from the routine
